summaryrefslogtreecommitdiff
path: root/lib/sqlalchemy/testing/plugin/plugin_base.py
diff options
context:
space:
mode:
authormike bayer <mike_mp@zzzcomputing.com>2020-04-20 13:04:32 +0000
committerGerrit Code Review <gerrit@bbpush.zzzcomputing.com>2020-04-20 13:04:32 +0000
commit88b085fc2e2710bc3c50d1d45f7585c7bef07673 (patch)
tree9334ce5518cf52c05f3ee18c31554e8a707a3ae7 /lib/sqlalchemy/testing/plugin/plugin_base.py
parent6e208823a66723c842975e0b75ec0e8b34ce0d2f (diff)
parent405fc9717048b0adc852a72da540048df7a8142a (diff)
downloadsqlalchemy-88b085fc2e2710bc3c50d1d45f7585c7bef07673.tar.gz
Merge "Rename py.test to pytest"
Diffstat (limited to 'lib/sqlalchemy/testing/plugin/plugin_base.py')
-rw-r--r--lib/sqlalchemy/testing/plugin/plugin_base.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/sqlalchemy/testing/plugin/plugin_base.py b/lib/sqlalchemy/testing/plugin/plugin_base.py
index 29dab098a..9b2f6911d 100644
--- a/lib/sqlalchemy/testing/plugin/plugin_base.py
+++ b/lib/sqlalchemy/testing/plugin/plugin_base.py
@@ -10,7 +10,7 @@
this module is designed to work as a testing-framework-agnostic library,
created so that multiple test frameworks can be supported at once
(mostly so that we can migrate to new ones). The current target
-is py.test.
+is pytest.
"""
@@ -206,7 +206,7 @@ def memoize_important_follower_config(dict_):
This invokes in the parent process after normal config is set up.
This is necessary as py.test seems to not be using forking, so we
start with nothing in memory, *but* it isn't running our argparse
callables, so we have to just copy all of that over.
@@ -206,7 +206,7 @@ def memoize_important_follower_config(dict_):
This invokes in the parent process after normal config is set up.
- This is necessary as py.test seems to not be using forking, so we
+ This is necessary as pytest seems to not be using forking, so we
start with nothing in memory, *but* it isn't running our argparse
callables, so we have to just copy all of that over.